@@ -1,6 +1,6 @@
 package Net::OAuth::LP::Models;
 
-# VERSION
+our $VERSION = '0.0010'; # VERSION
 
 use strictures 1;
 use Moo::Role;
@@ -8,8 +8,9 @@ use Method::Signatures;
 
 has 'c' => (is => 'rw',);
 
-method fetch         { }
-method fetch_by_link { }
+method find         { }
+method find_by_link { }
+method filter       { }
 
 method search ($path, $segments) {
     my $query = $self->c->__query_from_hash($segments);
@@ -17,6 +18,10 @@ method search ($path, $segments) {
     $self->c->get($uri);
 }
 
+method resource ($resource_link) {
+    $self->c->get($resource_link);
+}
+
 1;
 
 __END__
@@ -37,24 +42,27 @@ Client attribute to perform authenticated requests.
 
 =head1 METHODS
 
-=head2 B<fetch>
+=head2 B<find>
 
-Override in extended models to get a resource by item.
+Override in extended models.
 
-=head2 B<fetch_by_link>
+=head2 B<find_by_link>
 
-Override in extended models to get a resource by resource link.
+Override in extended models.
 
 =head2 B<search>
 
 Performs a search request against the target distribution.
 
-    $modal->search(
-        'ubuntu',
-        {   'ws.op'   => 'searchTasks',
-            'ws.size' => '10',
-            'status'  => 'New'
-        }
-    );
+    $lp->search('ubuntu', { 'ws.op' => 'searchTasks',
+                            'ws.size' => '10',
+                            'status' => 'New' });
+
+=head2 B<resource>
+
+Access resource endpoints directly, however, once API is feature complete
+this method shouldn't need to be referenced.
+
+    $lp->resource('launchpad_resource_link');
 
 =cut
