@@ -1,19 +1,20 @@
 package Net::OAuth::LP::Models::Activity;
 
-# VERSION
+our $VERSION = '0.0010'; # VERSION
 
 use strictures 1;
 use Moo;
 use Types::Standard qw(Str Int ArrayRef HashRef);
 use Method::Signatures;
 use List::Objects::WithUtils;
+use Data::Dump qw(pp);
 
 with('Net::OAuth::LP::Models');
 
 has 'activity' => (is => 'rw',);
 
 method entries {
-  array(@{$self->activity->entries});
+  array(@{$self->activity->{entries}});
 }
 
 1;
@@ -38,10 +39,6 @@ Interface to setting/retrieving bug activity information
     $b->find(1);
     say $b->activity->all;
 
-=head1 ATTRIBUTES
-
-=head2 B<activity>
-
 =head1 METHODS
 
 =head2 B<new>
