@@ -1,19 +1,20 @@
 package Net::OAuth::LP::Models::Messages;
 
-our $VERSION = '0.015_02'; # VERSION
+our $VERSION = '0.0010'; # VERSION
 
 use strictures 1;
 use Moo;
 use Types::Standard qw(Str Int ArrayRef HashRef);
 use Method::Signatures;
 use List::Objects::WithUtils;
+use Data::Dump qw(pp);
 
 with('Net::OAuth::LP::Models');
 
 has 'messages' => (is => 'rw',);
 
 method entries {
-  array(@{$self->messages->entries});
+  array(@{$self->messages->{entries}});
 }
 
 1;
@@ -38,16 +39,16 @@ Interface to setting/retrieving bug messages information
     $b->find(1);
     say $b->messages->all;
 
-=head1 ATTRIBUTES
-
-=head2 B<messages>
-
 =head1 METHODS
 
-In addition to those listed this object inherits methods from List::Objects::WithUtils.
-
 =head2 B<new>
 
     my $messages = Net::OAuth::LP::Models::Messages->new(messages => $bug->messages);
 
+=head2 B<all>
+
+Returns all messages results
+
+    say $messages->all;
+
 =cut
