@@ -1,19 +1,20 @@
 package Net::OAuth::LP::Models::Tasks;
 
-# VERSION
+our $VERSION = '0.0010'; # VERSION
 
 use strictures 1;
 use Moo;
 use Types::Standard qw(Str Int ArrayRef HashRef);
 use Method::Signatures;
 use List::Objects::WithUtils;
+use Data::Dump qw(pp);
 
 with('Net::OAuth::LP::Models');
 
 has 'tasks' => (is => 'rw',);
 
 method entries {
-  array(@{$self->tasks->entries});
+  array(@{$self->tasks->{entries}});
 }
 
 1;
@@ -38,16 +39,16 @@ Interface to setting/retrieving bug tasks information
     $b->find(1);
     say $b->tasks->all;
 
-=head1 ATTRIBUTES
-
-=head2 B<tasks>
-
 =head1 METHODS
 
-In addition to those listed this object inherits methods from List::Objects::WithUtils.
-
 =head2 B<new>
 
     my $tasks = Net::OAuth::LP::Models::Tasks->new(tasks => $bug->tasks);
 
+=head2 B<all>
+
+Returns all tasks results
+
+    say $tasks->all;
+
 =cut
